@@ -25,6 +25,10 @@ class GithubData(Repo) :
         self.set_data_fps()
         self.read_metadata()
 
+    def overwriting_clone(self , depth = 1) :
+        super().overwriting_clone()
+        self.set_data_fps()
+
     def _set_defualt_data_suffix(self) :
         for ky in data_file_suffixes.keys() :
             fps = self.ret_sorted_fpns_by_suf(ky)
